#!/bin/sh
#:
# Common Utility routines used by Brladmin installation scripts.
#
# Use . command to include in a particular file.
#
# $Id: common.sh,v 5.1 1998/03/31 13:30:16 markw Exp $
#
# Joe Drumgoole. 3-June-94.
# Modified for Brladmin 31-March 1996, Mark Winder. 
#

SPROOT=${SPROOT-/sproot}
export SPROOT

#
# System Type.
#
UNAME_M=`uname -m`
export UNAME_M
UNAME_S=`uname -s`
export UNAME_S

#
# Yes and No.
#
YES=0
export YES
NO=1
export NO

#
# Split these to prevent SCCS expanding percent I percent as sccs keyword.
#
YEAR="%y"
MONTH="%m"
DAY="%d"
HOUR="%H"
MINUTE="%M"
DATE=`date +"$YEAR$MONTH$DAY$HOUR$MINUTE"`
export DATE

#
# We only support Solaris and SCO/UNIX for now.
#
if [ "${UNAME_M}" = "i386" ] ; then

OS=sco

else
   if [ "${UNAME_S}" = "SunOS" ] ; then
      OS=sol
   elif [ "${UNAME_S}" = "AIX" ] ; then
      OS=aix
   elif [ "${UNAME_S}" = "OSF1" ]; then
      OS=alpha
   elif [ "${UNAME_S}" = "Linux" ] ; then
      OS=Linux
   fi
fi
export OS

if [ $OS = aix ] || [ $OS = Linux ]; then
    AWK=awk
else
    AWK=nawk
fi
export AWK

if [ $OS = Linux ]; then
# use bash echo
    ECHO="echo -e"
else
    ECHO=echo
fi
export ECHO

FATAL=0
export FATAL

#
# Temporary data file used internally.
#
DATA=/tmp/spdata
export DATA

#
# Need to install the kit into somewhere other that /sproot to avoid
# overwriting the old installation.
#
INSTALLDIR=$BASEDIR
export INSTALLDIR

#
# Scripts, before and after copying from INSTALLDIR
#

ISCRIPTS=$INSTALLDIR$SPROOT/scripts
export ISCRIPTS
SCRIPTS=$SPROOT/brlscripts
export SCRIPTS

#
# Path to binaries used during installation.
#
BINDIR=${SPROOT}/bin
export BINDIR

#
# Kit names used by various scripts.
#
#
# Server.
#
SERVERKIT=ERLsrvr
export SERVERKIT

#
# The scripts dir is shared between the server client and admin kits.
# The files dir is preserved from the previous installation.
#

INSTALLSERVERDIRS="bin dbase files man masters scripts"
export INSTALLSERVERDIRS

MAKESERVERDIRS="files nodes spdbvols cfiles erlstat tmp"
export MAKESERVERDIRS

ALLSERVERDIRS="$INSTALLSERVERDIRS $MAKESERVERDIRS"
export ALLSERVERDIRS

#
# Client.
#
CLIENTKIT=ERLclnt
export CLIENTKIT

#
# Adminstration.
#
ADMINKIT=ERLadmn
export ADMINKIT

GetString()
{
#
# $1 = Parameter to read
# $2 = String to use for prompt.
# $3 = Default value
#
    while $ECHO "$2 [$3]: \c"; read $1
          # substitute default if required (note quoting for rescan)
          eval true \${$1:=\"$3\"}
          # loop exit condition is nonblank result (note quoting for rescan)
          eval [ ! \"\$$1\" ]
    do
        :
    done
}

GetNumber()
{
    until GetString $1 "$2" $3
          eval echo \$$1 | grep "^[     ]*[0-9]*[     ]*$" >/dev/null
    do
        :
    done
}

YorN() {
#
# Prompt user, they must reply y or n.
#
   YES=0
   NO=1
   while $ECHO "$* (y/n) :\c"
   do
      read yn rest
      case $yn in
         [yY]) return $YES ;;
         [nN]) return $NO ;;
            *) echo "Please answer Y or N." ;;
      esac
   done
} # end YorN.

line ()
{
echo "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
}

warning()
{
  line
  echo "Warning :"
  echo "Warning : $*"
  echo "Warning :"
  line

}

error()
{
  line
  echo "Error :"
  echo "Error : $*"
  echo "Error :"
  line
}

messagepart()
{
  echo "~ $*"
}

message()
{
  line
  messagepart $*
  line
}

move()
{
   mv $* || { err=$?; error "Failed to execute: mv $*"; exit $err; }
}

spcopy()

{
   cp $* || { err=$?; error "Failed to execute: cp $*"; exit $err; }
}

pause()
{
   $ECHO "Press ENTER: \c"
   read dummy
}
